Crate xio_jobset

Crate xio_jobset 

A module containing data structures for XIO job sets.

Structs

ChannelAssignment
An assignment of a parameter to a XIO module channel.
Command
A command which can be executed in a job.
CommandDescription
The description of a command and the conditions belonging to it.
Condition
A condition which gets checked while a command is running.
ConditionDescription
The caption of a condition;
HardwareAssignment
The assignment of variables mapped to a hardware board
Job
A job, defined by a list of commands.
JobSet
A complete job set.
Metadata
Metadata of a job set.
ParameterDescription
The description of a parameter.
ParameterSet
A set of parameters (a.k.a. parameter layer).
ParameterSetMetadata
Metadata for a parameter set.

Traits

ExtractDescriptions
Extract all descriptions from an item.