A module containing data structures for XIO job sets.
Structs
- Channel
Assignment - An assignment of a parameter to a XIO module channel.
- Command
- A command which can be executed in a job.
- Command
Description - The description of a command and the conditions belonging to it.
- Condition
- A condition which gets checked while a command is running.
- Condition
Description - The caption of a condition;
- Hardware
Assignment - The assignment of variables mapped to a hardware board
- Job
- A job, defined by a list of commands.
- JobSet
- A complete job set.
- Metadata
- Metadata of a job set.
- Parameter
Description - The description of a parameter.
- Parameter
Set - A set of parameters (a.k.a. parameter layer).
- Parameter
SetMetadata - Metadata for a parameter set.
Traits
- Extract
Descriptions - Extract all descriptions from an item.